@@ -1,9 +1,7 @@
 # This code is released into public domain.
-# 
-# anatoly techtonik <techtonik@gmail.com>
-#
 
-__version__ = '0.2'
+__version__ = '0.3'
+__author__ = 'anatoly techtonik <techtonik@gmail.com>'
 
 import datetime
 import inspect
@@ -56,7 +54,10 @@ class XTracer(object):
                 # by analogy with PHP require() trace in Xdebug, the format is
                 # <mod.name>(module_location) file_imported_from:line
                 param = filename
-                filename = self._strip_cwd(frame.f_back.f_code.co_filename)
+                if frame.f_back:
+                   filename = self._strip_cwd(frame.f_back.f_code.co_filename)
+                else:
+                   filename = ''  # top frame, no parent
             # skip paths mentioned in trace_filter
             if (funcname[0] is not '<' # not module import
                     and any( [filename.startswith(x) for x in self.filter] )):
